﻿Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.DesktopEdition

Public Class Form1
   Private miNamedViewNumber As Integer = 1
   Private moCoordinateSystemInfo As New CoordinateSystemInfo
   Private moNamedViewCollection As New NamedViewCollection
   Private msInstructions As String =
           "1. Create two or three Named Views by clicking button 'Add Named View'. They will automatically be added to the NamedViewsCollection." & vbCrLf &
           "2. Serialize the NamedViewCollection. It will be saved to a file and the text will be written into the textbox on the right." & vbCrLf &
           "3. Now deserialize the NamedViewCollection. Set a breakpoint in the code and notice that, after it is deserialized it contains no items."


   Private Sub Form1_Load(sender As Object, e As System.EventArgs) Handles Me.Load
      txtInstructions.Text = msInstructions
      Dim sPath As String = "..\..\Data\United States.shp"
      Dim oShapefile As New ShapeFileFeatureLayer(sPath)
      oShapefile.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.SimpleColors.Blue, 1)
      oShapefile.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20
      Dim oLayerOverLay As New LayerOverlay
      oLayerOverLay.Layers.Add(oShapefile)
      oShapefile.Open()
      WindowState = FormWindowState.Maximized
      With moCoordinateSystemInfo
         .DistanceUnits = GeographyUnit.DecimalDegree
         .IsCustom = False
         .IsProjected = False
         .Name = "GCS_North_American_1927"
         .ParameterString = "+proj=longlat+ellps=clrk66+datum=NAD27+no_defs"
         .SRID = 4367
      End With


      WinformsMap1.CurrentExtent = oShapefile.GetBoundingBox
      WinformsMap1.Overlays.Add(oLayerOverLay)
      WinformsMap1.Refresh()
   End Sub

   Private Sub btnSerialize_Click(sender As System.Object, e As System.EventArgs) Handles btnSerialize.Click
      Dim oGeoSerializer As New GeoSerializer()
      Dim sPath As String = GetUserFolder() & "NamedViews.xml"
      TextBox1.Text = oGeoSerializer.Serialize(moNamedViewCollection)
      oGeoSerializer.Serialize(moNamedViewCollection, sPath)
   End Sub
   Private Sub btnDeSerialize_Click(sender As Object, e As System.EventArgs) Handles btnDeSerialize.Click
      Dim oGeoSerializer As New GeoSerializer()
      Dim sPath As String = GetUserFolder() & "NamedViews.xml"
      moNamedViewCollection = CType(oGeoSerializer.Deserialize(sPath, IO.FileAccess.Read), NamedViewCollection)
      moNamedViewCollection = CType(oGeoSerializer.Deserialize(TextBox1.Text), NamedViewCollection)
   End Sub

   Private Sub btnAddNamedView_Click(sender As System.Object, e As System.EventArgs) Handles btnAddNamedView.Click
      '***** Create a name for the Named View
      Dim sNamedView As String = "Named View " & miNamedViewNumber.ToString
      miNamedViewNumber += 1

      '***** Create a named View
      Dim oNamedView As New NamedView(moCoordinateSystemInfo, WinformsMap1.CurrentExtent, sNamedView)

      '***** Add it to the collection
      moNamedViewCollection.Add(oNamedView)



   End Sub
   Public Function GetUserFolder() As String
      Dim sBasePath As String
      Dim sApplicationPath As String

      sBasePath = Environment.GetFolderPath(Environment.SpecialFolder.ApplicationData)
      sApplicationPath = Application.CompanyName & "\" & Application.ProductName & "\"
      If Not IO.Directory.Exists(sBasePath & "\" & sApplicationPath) Then
         IO.Directory.CreateDirectory(sBasePath & "\" & sApplicationPath)
      End If

      Return sBasePath & "\" & sApplicationPath

   End Function

End Class
